"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runInitCommand = void 0;
const tslib_1 = require("tslib");
const loggin_1 = require("../../core/loggin");
const behaviors_1 = require("../../core/processing/behaviors");
const collect_rc_json_1 = require("./processes/collect-rc-json");
const utils_1 = require("../../global/utils");
const utils_2 = require("./utils");
const update_rc_json_1 = require("./processes/update-rc-json");
const generate_userflow_1 = require("./processes/generate-userflow");
const generate_workflow_1 = require("./processes/generate-workflow");
const generate_lh_budgets_1 = require("./processes/generate-lh-budgets");
const constants_1 = require("./constants");
function runInitCommand(argv) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { interactive } = (0, utils_1.getGlobalOptionsFromArgv)(argv);
        const _a = (0, utils_2.getInitCommandOptionsFromArgv)(argv), { generateFlow, generateGhWorkflow, generateBudgets, lhr } = _a, cfg = tslib_1.__rest(_a, ["generateFlow", "generateGhWorkflow", "generateBudgets", "lhr"]);
        (0, loggin_1.logVerbose)('Init options: ', Object.assign({ interactive, generateFlow, generateGhWorkflow, generateBudgets, lhr }, cfg));
        yield (0, behaviors_1.run)([
            collect_rc_json_1.collectRcJson,
            update_rc_json_1.updateRcJson,
            (0, generate_userflow_1.handleFlowGeneration)({ interactive: !!interactive, generateFlow }),
            (0, generate_workflow_1.handleGhWorkflowGeneration)({ generateGhWorkflow }),
            (0, generate_lh_budgets_1.handleBudgetsGeneration)({ generateBudgets, lhr }),
        ])(cfg);
        (0, loggin_1.log)(constants_1.SETUP_CONFIRM_MESSAGE);
        // @TODO move to constants
        (0, loggin_1.log)('To execute a user flow run `npx user-flow` or `npx user-flow collect`');
    });
}
exports.runInitCommand = runInitCommand;
//# sourceMappingURL=command-impl.js.map