"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleBudgetsGeneration = exports.generateLightHouseBudgetProcess = exports.generateLhBudgets = exports.writeBudgetsFile = exports.derivedBudgets = exports.defaultBudgets = exports.budgetsFileExist = void 0;
const tslib_1 = require("tslib");
const node_path_1 = require("node:path");
const node_fs_1 = require("node:fs");
const node_process_1 = require("node:process");
const file_1 = require("../../../core/file");
const loggin_1 = require("../../../core/loggin");
const constants_1 = require("../constants");
const behaviors_1 = require("../../../core/processing/behaviors");
const derive_budgets_from_lhr_1 = require("../derive-budgets-from-lhr");
const budgetsFileExist = (path) => {
    return (0, file_1.readFile)(path) !== '';
};
exports.budgetsFileExist = budgetsFileExist;
const defaultBudgets = () => {
    (0, loggin_1.logVerbose)('New budgets used');
    const tplFileName = constants_1.BudgetsExampleMap['budgets'];
    const exampleSourceLocation = (0, node_path_1.join)(__dirname, '..', 'static', tplFileName);
    return (0, file_1.readFile)(exampleSourceLocation, { fail: true }).toString();
};
exports.defaultBudgets = defaultBudgets;
const derivedBudgets = (lhr) => {
    const lhrJson = (0, file_1.readFile)(lhr);
    if (lhrJson === '') {
        throw new Error(`Lighthouse report ${lhr} to derive budgets from is not given.`);
    }
    (0, loggin_1.logVerbose)('Budgets derived from lhr');
    return JSON.stringify((0, derive_budgets_from_lhr_1.deriveBudgetsFromLhr)(JSON.parse(lhrJson)));
};
exports.derivedBudgets = derivedBudgets;
const budgets = (lhr) => {
    return lhr ? (0, exports.derivedBudgets)(lhr) : (0, exports.defaultBudgets)();
};
function writeBudgetsFile(path, name, budgets) {
    if (!(0, node_fs_1.existsSync)(path)) {
        (0, node_fs_1.mkdirSync)(path, { recursive: true });
        (0, loggin_1.logVerbose)(`setup budgets folder ${path}`);
    }
    (0, file_1.writeFile)((0, node_path_1.join)(path, name), budgets);
}
exports.writeBudgetsFile = writeBudgetsFile;
function generateLhBudgets(cfg) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const BUDGETS_FILE_NAME = 'budget.json';
        if (!(0, exports.budgetsFileExist)(BUDGETS_FILE_NAME)) {
            writeBudgetsFile((0, node_process_1.cwd)(), BUDGETS_FILE_NAME, budgets(cfg.lhr));
        }
        else {
            (0, loggin_1.logVerbose)(`Budgets ${BUDGETS_FILE_NAME} already generated.`);
        }
        return Promise.resolve(cfg);
    });
}
exports.generateLhBudgets = generateLhBudgets;
function hasGenerateBudgetsInput(generateBudgets) {
    return () => !!generateBudgets;
}
function generateLightHouseBudgetProcess(lhr) {
    return (cfg) => generateLhBudgets(Object.assign(Object.assign({}, cfg), { lhr }));
}
exports.generateLightHouseBudgetProcess = generateLightHouseBudgetProcess;
function handleBudgetsGeneration({ generateBudgets, lhr }) {
    return (0, behaviors_1.ifThenElse)(hasGenerateBudgetsInput(generateBudgets), generateLightHouseBudgetProcess(lhr));
}
exports.handleBudgetsGeneration = handleBudgetsGeneration;
//# sourceMappingURL=generate-lh-budgets.js.map