"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleFlowGeneration = exports.userflowIsNotCreated = exports.getExamplePathDest = void 0;
const tslib_1 = require("tslib");
const node_path_1 = require("node:path");
const node_fs_1 = require("node:fs");
const file_1 = require("../../../core/file");
const loggin_1 = require("../../../core/loggin");
const constants_1 = require("../constants");
const behaviors_1 = require("../../../core/processing/behaviors");
const confirm_to_process_1 = require("../../../core/prompt/confirm-to-process");
const exampleName = 'basic-navigation';
function getExamplePathDest(folder) {
    const fileName = constants_1.FlowExampleMap[exampleName];
    return (0, node_path_1.join)(folder, fileName);
}
exports.getExamplePathDest = getExamplePathDest;
const userflowIsNotCreated = (cfg) => {
    return (0, file_1.readFile)(getExamplePathDest(cfg.collect.ufPath)) === '';
};
exports.userflowIsNotCreated = userflowIsNotCreated;
function generateUserFlow(cliCfg) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const ufPath = cliCfg.collect.ufPath;
        // DX create directory if it does ot exist
        try {
            (0, node_fs_1.readdirSync)(ufPath);
        }
        catch (e) {
            (0, node_fs_1.mkdirSync)(ufPath, { recursive: true });
        }
        const tplFileName = constants_1.FlowExampleMap[exampleName];
        const exampleSourceLocation = (0, node_path_1.join)(__dirname, '..', 'static', tplFileName);
        const exampleDestination = (0, node_path_1.join)(ufPath, tplFileName);
        if ((0, file_1.readFile)(exampleDestination) !== '') {
            (0, loggin_1.logVerbose)(`User flow ${exampleName} already generated under ${exampleDestination}.`);
            return Promise.resolve(cliCfg);
        }
        const fileContent = (0, file_1.readFile)(exampleSourceLocation, { fail: true }).toString();
        (0, file_1.writeFile)(exampleDestination, fileContent);
        (0, loggin_1.log)(`setup user-flow for basic navigation in ${ufPath} successfully`);
        return Promise.resolve(cliCfg);
    });
}
const interactiveAndGenerateFlowNotPassed = (interactive, generateFlow) => {
    return () => interactive && generateFlow === undefined;
};
function handleFlowGeneration({ generateFlow, interactive }) {
    return (0, behaviors_1.ifThenElse)(interactiveAndGenerateFlowNotPassed(interactive, generateFlow), (0, confirm_to_process_1.confirmToProcess)({
        prompt: constants_1.PROMPT_INIT_GENERATE_FLOW,
        process: generateUserFlow,
        precondition: exports.userflowIsNotCreated
    }), 
    // else `withFlow` is used and true
    (0, behaviors_1.ifThenElse)(() => !!generateFlow, 
    // generate the file => else do nothing
    generateUserFlow));
}
exports.handleFlowGeneration = handleFlowGeneration;
//# sourceMappingURL=generate-userflow.js.map