"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleGhWorkflowGeneration = exports.generateGhWorkflowFile = exports.getExamplePathDest = void 0;
const tslib_1 = require("tslib");
const path_1 = require("path");
const file_1 = require("../../../core/file");
const loggin_1 = require("../../../core/loggin");
const fs_1 = require("fs");
const constants_1 = require("../constants");
const behaviors_1 = require("../../../core/processing/behaviors");
const exampleName = 'basic-workflow';
const destPath = (0, path_1.join)('.github', 'workflows');
function getExamplePathDest() {
    const fileName = constants_1.GhWorkflowExampleMap[exampleName];
    if (!fileName) {
        throw new Error(`workflowExample ${exampleName} is not registered`);
    }
    return (0, path_1.join)(destPath, fileName);
}
exports.getExamplePathDest = getExamplePathDest;
function generateGhWorkflowFile(cliCfg) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const tplFileName = constants_1.GhWorkflowExampleMap[exampleName];
        const exampleSourceLocation = (0, path_1.join)(__dirname, '..', 'static', tplFileName);
        const exampleDestination = getExamplePathDest();
        if ((0, file_1.readFile)(exampleDestination) !== '') {
            (0, loggin_1.logVerbose)(`User flow ${exampleName} already generated under ${exampleDestination}.`);
            return Promise.resolve(cliCfg);
        }
        const fileContent = (0, file_1.readFile)(exampleSourceLocation, { fail: true }).toString();
        if (!(0, fs_1.existsSync)(destPath)) {
            (0, fs_1.mkdirSync)(destPath, { recursive: true });
            (0, loggin_1.logVerbose)(`setup workflow folder ${destPath}`);
        }
        (0, file_1.writeFile)(exampleDestination, fileContent);
        (0, loggin_1.log)(`setup workflow for user-flow integration in the CI in ${exampleDestination} successfully`);
        return Promise.resolve(cliCfg);
    });
}
exports.generateGhWorkflowFile = generateGhWorkflowFile;
function handleGhWorkflowGeneration({ generateGhWorkflow }) {
    return (0, behaviors_1.ifThenElse)(
    // if `withFlow` is not used in the CLI is in interactive mode
    () => generateGhWorkflow === true, 
    // generate the file => else do nothing
    generateGhWorkflowFile);
}
exports.handleGhWorkflowGeneration = handleGhWorkflowGeneration;
//# sourceMappingURL=generate-workflow.js.map